// ===================================================================
// $Id:$
//
// colorcnv.h
//              Header file for color conversion.
//
// Initial coding by Vlastimil Havran, December, 2010.

#ifndef __COLORCNV_H__
#define __COLORCNV_H__

// Common headers
#include "configh.h"

// The number of entries in the table for Spectral->XYZ conversion
const int wavelengthNumberXYZ = 381;

// Return the coefficient for conversion from spectral to XYZ.
// Wavelength is given in meters [SI units] should be in the order
// 360e-9 to 740e-9 [m]. Returns false if success, true if the
// input wavelength is out of the range. Sets the values for
// integration correspondingly.
bool
GetCoeffsSpectrumToXYZ(double &coeffX, double &coeffY, double &coeffZ, 
		       double wavelength); // input

// Conversion of the spectral color to the artificial primaries XYZ
void
SpectralToXYZ(float &vX, float &vY, float &vZ,  // output
	      float spectralValue[], // input
	      float wavelengthBeg, float wavelengthEnd,
	      int cntWavelengths);

// Conversion from XYZ to sRGB (standard RGB) color
void
XYZ_to_sRGB(float X, float Y, float Z, // input
	    float &R, float &G, float &B); // output

#endif // __COLORCNV_H__

